# encoding: UTF-8
require 'active_record'

namespace :db do
  desc "Seed production environment with real data."

  task :production_seeds do |t|
    Authorization.ignore_access_control(true)
    
    puts "Create group typess.."
    GroupType.delete_all
    group_types = [
      'Styrende organ',
      'Arrangerende',
      'Drift',
      'Kunstneriske',
      'Media',
      'Festivaler',
      'Administrative',
      'Andre grupperinger'
    ]
    group_types.each_with_index do |gt, priority|
      GroupType.create!(
        description: gt,
        priority: priority
      )
    end
    
    puts "Create groups.."
    Group.delete_all
    Group.create([
      { name: "Arkivet", abbreviation: "", group_type: GroupType.find_by_description('Administrative') },
      { name: "Regi", abbreviation: "", group_type: GroupType.find_by_description('Drift') },
      { name: "ISFiT 2011", abbreviation: "", group_type: GroupType.find_by_description('Festivaler') },
      { name: "Samfundets byggekomite", abbreviation: "SBK", group_type: GroupType.find_by_description('Administrative') },
      { name: "Finansstyret", abbreviation: "FS", group_type: GroupType.find_by_description('Styrende organ') },
      { name: "Propheten", abbreviation: "", group_type: GroupType.find_by_description('Media') },
      { name: "Kulturutvalget", abbreviation: "KU", group_type: GroupType.find_by_description('Arrangerende') },
      { name: "IT-komiteen", abbreviation: "ITK", group_type: GroupType.find_by_description('Drift') },
      { name: "Kontrollkontoret", abbreviation: "KK", group_type: GroupType.find_by_description('Drift') },
      { name: "Radio Revolt", abbreviation: "Radion", group_type: GroupType.find_by_description('Media') },
      { name: "Big Mama's Cowboys", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "S. Møller Storband", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Lørdagskomitéen", abbreviation: "LK", group_type: GroupType.find_by_description('Arrangerende') },
      { name: "Profilgruppa", abbreviation: "Profil", group_type: GroupType.find_by_description('Drift') },
      { name: "Markedsføringsgjengen", abbreviation: "MG", group_type: GroupType.find_by_description('Drift'),
        short_description: "Markedsføringsgjengen har fire avdelinger med sine egne arbeidsområder: info, marked, layout og web. Sammen har disse ansvar for Samfundets profil utad, derunder nettsiden www.samfundet.no." },
      { name: "Musikerlåfte", abbreviation: "Låfte", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Diversegjengen", abbreviation: "DG", group_type: GroupType.find_by_description('Drift') },
      { name: "Videokomitéen", abbreviation: "VK", group_type: GroupType.find_by_description('Drift') },
      { name: "Trondhjems Kvinnelige Studentersangforening", abbreviation: "TKS", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Rådet", abbreviation: "", group_type: GroupType.find_by_description('Styrende organ') },
      { name: "Strindens Prom Orchester", abbreviation: "SPO", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Kjellerbandet", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Leisure Suit Lovers", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Pirum", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Snaustrinda", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Symfoniorkesteret", abbreviation: "Symforch", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Salongorkestret", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Knauskoret", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Trondheim InterRail Centre", abbreviation: "TIRC", group_type: GroupType.find_by_description('Andre grupperinger') },
      { name: "Gjengsekretariatet", abbreviation: "GS", group_type: GroupType.find_by_description('Administrative') },
      { name: "Akademisk Radioklubb", abbreviation: "ARK", group_type: GroupType.find_by_description('Drift') },
      { name: "Under Dusken", abbreviation: "UD", group_type: GroupType.find_by_description('Media') },
      { name: "UKA-11", abbreviation: "", group_type: GroupType.find_by_description('Festivaler') },
      { name: "Sitting ducks", abbreviation: "SD", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Trondhjems Studentersangforening", abbreviation: "TSS", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Student-TV", abbreviation: "STV", group_type: GroupType.find_by_description('Media') },
      { name: "Kafé- og Serveringsgjengen", abbreviation: "KSG", group_type: GroupType.find_by_description('Arrangerende') },
      { name: "Klubbstyret", abbreviation: "KLST", group_type: GroupType.find_by_description('Arrangerende') },
      { name: "Studentersamfundets Interne Teater", abbreviation: "SIT", group_type: GroupType.find_by_description('Kunstneriske') },
      { name: "Styret", abbreviation: "", group_type: GroupType.find_by_description('Styrende organ') },
      { name: "Gjengsjefkollegiet", abbreviation: "GSK", group_type: GroupType.find_by_description('Administrative') },
      { name: "Forsterkerkomiteen", abbreviation: "FK", group_type: GroupType.find_by_description('Drift') },
      { name: "Fotogjengen", abbreviation: "FG", group_type: GroupType.find_by_description('Drift') },
      { name: "Candiss", abbreviation: "", group_type: GroupType.find_by_description('Kunstneriske') },
    ])
    
    web_ids = [
      1008444,
      1009230,
      1001037,
      1006732,
      1003184,
      1013850,
      1019999,
      1006751,
      1006752,
      1006753,
      1014694
    ]
    
    puts "Create roles.."
    Role.delete_all
    
    lim_web_role = Role.find_or_create_by_title(title: "lim_web", name: "Superuser", description: "Superrolle for alle i mgweb.")
    
    web_ids.each do |web_id|
      web_member = Member.find_by_medlem_id web_id
      web_member.roles << lim_web_role unless web_member.nil?
    end
    
    Group.all.each do |group|
      group_leader = Role.create!(title: group.group_leader_role.to_s, name: "Gjengsjef", description: "Rolle for gjengsjef for #{group.name}.", group: group)
      Role.create!(title: group.admission_responsible_role.to_s, name: "Opptaksansvarlig", description: "Rolle for opptaksperson for #{group.name}.", group: group, role: group_leader)
      Role.create!(title: group.short_name.urlify, name: group.name, description: "Rolle for alle medlemmer av #{group.name}.", group: group, role: group_leader)
    end
  end
end
